==> trilinos_12.18.1.orig.tar.gz: Trilinos-trilinos-release-12-18-1/packages/piro/src/Piro_TransientDecorator.hpp <==
// @HEADER
// ************************************************************************
//
//        Piro: Strategy package for embedded analysis capabilitites
//                  Copyright (2010) Sandia Corporation
//
// Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
// the U.S. Government retains certain rights in this software.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// 3. Neither the name of the Corporation nor the names of the
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// Questions? Contact Andy Salinger (agsalin@sandia.gov), Sandia
// National Laboratories.
//
// ************************************************************************
// @HEADER

#ifndef PIRO_TRANSIENTDECORATOR_H
#define PIRO_TRANSIENTDECORATOR_H

#include <iostream>

#include "Thyra_ModelEvaluatorDefaultBase.hpp"
#include "Teuchos_ParameterList.hpp"
#include "Teuchos_RCP.hpp"

namespace Piro {

template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
class TransientDecorator
    : public Thyra::ModelEvaluatorDefaultBase<Scalar> {

  public:

  /** \name Constructors/initializers */
  //@{

  TransientDecorator(){}

  //@}

  Teuchos::RCP<Thyra::VectorBase<Scalar> > get_x_dotdot() const { return xDotDot; }

  void set_x_dotdot(const Teuchos::RCP<Thyra::VectorBase<Scalar> > &xdd) const {  xDotDot = xdd; }
  void set_x_dotdot_data(const Teuchos::RCP<Thyra::VectorBase<Scalar> > &xdd) const {  assign(xDotDot.ptr(), *xdd); }

  Scalar get_omega() const { return omega; };

  void set_omega(const Scalar oo) const {omega = oo; }

  void printVec(const Teuchos::RCP<const Thyra::VectorBase<Scalar> > &vec) const {
       std::cout << "GAH Vector is: " << std::endl;
       for(int ii=0; ii < vec->space()->dim(); ii++)
          std::cout << get_ele(*vec, ii) << std::endl;
  }

  Thyra::ModelEvaluatorBase::Derivative<Scalar> get_DgDx_dotdot(int j) const { return DgDx_dotdot_[j]; }

  /** \brief Precondition: <tt>supports(OUT_ARG_DgDx_dot,j)==true</tt>.  */
  void set_DgDx_dotdot(int j, const Thyra::ModelEvaluatorBase::Derivative<Scalar> &DgDx_dotdot_j){
          DgDx_dotdot_[j] = DgDx_dotdot_j;
       }

  protected:

   mutable Teuchos::RCP<Thyra::VectorBase<Scalar> > xDotDot;
   mutable Scalar omega;
   mutable Teuchos::Array<Thyra::ModelEvaluatorBase::Derivative<Scalar> > DgDx_dotdot_;

};


}

#endif

==> trilinos_13.2.0.orig.tar.gz: Trilinos-trilinos-release-13-2-0/packages/piro/src/Piro_TransientDecorator.hpp <==
// @HEADER
// ************************************************************************
//
//        Piro: Strategy package for embedded analysis capabilitites
//                  Copyright (2010) Sandia Corporation
//
// Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
// the U.S. Government retains certain rights in this software.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// 3. Neither the name of the Corporation nor the names of the
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// Questions? Contact Andy Salinger (agsalin@sandia.gov), Sandia
// National Laboratories.
//
// ************************************************************************
// @HEADER

#ifndef PIRO_TRANSIENTDECORATOR_H
#define PIRO_TRANSIENTDECORATOR_H

#include <iostream>

#include "Thyra_ModelEvaluatorDefaultBase.hpp"
#include "Teuchos_ParameterList.hpp"
#include "Teuchos_RCP.hpp"

namespace Piro {

template <typename Scalar>
class TransientDecorator
    : public Thyra::ModelEvaluatorDefaultBase<Scalar> {

  public:

  /** \name Constructors/initializers */
  //@{

  TransientDecorator(){}

  //@}

  Teuchos::RCP<Thyra::VectorBase<Scalar> > get_x_dotdot() const { return xDotDot; }

  void set_x_dotdot(const Teuchos::RCP<Thyra::VectorBase<Scalar> > &xdd) const {  xDotDot = xdd; }
  void set_x_dotdot_data(const Teuchos::RCP<Thyra::VectorBase<Scalar> > &xdd) const {  assign(xDotDot.ptr(), *xdd); }

  Scalar get_omega() const { return omega; };

  void set_omega(const Scalar oo) const {omega = oo; }

  void printVec(const Teuchos::RCP<const Thyra::VectorBase<Scalar> > &vec) const {
       std::cout << "GAH Vector is: " << std::endl;
       for(int ii=0; ii < vec->space()->dim(); ii++)
          std::cout << get_ele(*vec, ii) << std::endl;
  }

  Thyra::ModelEvaluatorBase::Derivative<Scalar> get_DgDx_dotdot(int j) const { return DgDx_dotdot_[j]; }

  /** \brief Precondition: <tt>supports(OUT_ARG_DgDx_dot,j)==true</tt>.  */
  void set_DgDx_dotdot(int j, const Thyra::ModelEvaluatorBase::Derivative<Scalar> &DgDx_dotdot_j){
          DgDx_dotdot_[j] = DgDx_dotdot_j;
       }

  protected:

   mutable Teuchos::RCP<Thyra::VectorBase<Scalar> > xDotDot;
   mutable Scalar omega;
   mutable Teuchos::Array<Thyra::ModelEvaluatorBase::Derivative<Scalar> > DgDx_dotdot_;

};


}

#endif
